@@ -1,7 +1,8 @@
-.plotMonotone <- function(dt, timeStep, variable, variable2Axe = NULL, confInt = NULL, maxValue,
-                          main = NULL, ylab = NULL, highlight = FALSE, stepPlot = FALSE, drawPoints = FALSE, ...) {
+.plotMonotone <- function(dt, timeStep, variable, variable2Axe = NULL, typeConfInt = FALSE, confInt = NULL, maxValue,
+                          main = NULL, ylab = NULL, highlight = FALSE, stepPlot = FALSE, drawPoints = FALSE, language = "en", 
+                          label_variable2Axe = NULL, ...) {
   
-  uniqueElements <- sort(unique(dt$element))
+  uniqueElements <- as.character(sort(unique(dt$element)))
   plotConfInt <- FALSE
   # If dt contains several Monte-Carlo scenario, compute aggregate statistics
   if (is.null(dt$mcYear)) {
@@ -15,33 +16,45 @@
       y = sort(value, decreasing = TRUE)
     ), by = .(element, mcYear)]
     
-    if (confInt == 0) {
-      dt <- dt[, .(y = mean(y)), by = .(element, x)]
-    } else {
-      plotConfInt <- TRUE
-      uniqueElements <- sort(unique(dt$element))
-      
-      alpha <- (1 - confInt) / 2
-      dt <- dt[, .(y = c(mean(y), quantile(y, c(alpha, 1 - alpha))),
-                   suffix = c("", "_l", "_u")), 
-               by = .(x, element)]
-      dt[, element := paste0(element, suffix)]
+    if(typeConfInt){
+      if (confInt == 0) {
+        dt <- dt[, .(y = mean(y)), by = .(element, x)]
+      } else {
+        plotConfInt <- TRUE
+        uniqueElements <- as.character(sort(unique(dt$element)))
+        
+        alpha <- (1 - confInt) / 2
+        dt <- dt[, .(y = c(mean(y), quantile(y, c(alpha, 1 - alpha))),
+                     suffix = c("", "_l", "_u")), 
+                 by = .(x, element)]
+        dt[, element := paste0(element, suffix)]
+      }
     }
   }
   
   variable <- paste0(variable, collapse = " ; ")
   if (is.null(ylab)) ylab <- variable
-  if (is.null(main) | isTRUE(all.equal("", main))) main <- paste("Monotone of", variable)
+  if (is.null(main) | isTRUE(all.equal("", main))){
+    main <- paste(.getLabelLanguage("Monotone of", language), variable)
+  }
+  
+  if(!is.null(variable2Axe) && length(variable2Axe) > 0){
+    ylab2 <- paste0(label_variable2Axe, collapse = " ; ")
+  } else {
+    ylab2 <- NULL
+  }
   
   .plotStat(dt, ylab = ylab, main = main, uniqueElements = uniqueElements, variable2Axe = variable2Axe,
-            highlight = highlight, stepPlot = stepPlot, drawPoints = drawPoints, ...)
+            plotConfInt = plotConfInt, highlight = highlight, stepPlot = stepPlot, drawPoints = drawPoints, 
+            ylab2 = ylab2, ...)
   
 }
 
 .density <- function(dt, timeStep, variable, variable2Axe = NULL, minValue = NULL, maxValue = NULL, 
-                     main = NULL, ylab = NULL, highlight = FALSE, stepPlot = FALSE, drawPoints = FALSE, ...) {
+                     main = NULL, ylab = NULL, highlight = FALSE, stepPlot = FALSE, drawPoints = FALSE, 
+                     language = "en", label_variable2Axe = NULL, ...) {
   
-  uniqueElements <- sort(unique(dt$element))
+  uniqueElements <- as.character(sort(unique(dt$element)))
   
   xbins <- .getXBins(dt$value, minValue, maxValue)
   if (is.character(xbins)) return(xbins)
@@ -54,18 +67,30 @@
   dt <- dt[, .getDensity(value), by = element]
   
   variable <- paste0(variable, collapse = " ; ")
-  if (is.null(ylab)) ylab <- "Density"
-  if (is.null(main) | isTRUE(all.equal("", main))) main <- paste("Density of", variable)
+  if (is.null(ylab)){
+    # ylab <- .getLabelLanguage("Density", language)
+    ylab <- variable
+  }
+
+  if(!is.null(variable2Axe) && length(variable2Axe) > 0){
+    ylab2 <- paste0(label_variable2Axe, collapse = " ; ")
+  } else {
+    ylab2 <- NULL
+  }
+  
+  if (is.null(main) | isTRUE(all.equal("", main))){
+    main <- paste(.getLabelLanguage("Density of", language), variable)
+  }
   
   .plotStat(dt, ylab = ylab, main = main, uniqueElements = uniqueElements,variable2Axe = variable2Axe, 
-            highlight = highlight, stepPlot = stepPlot, drawPoints = drawPoints,...)
+            highlight = highlight, stepPlot = stepPlot, drawPoints = drawPoints, ylab2 = ylab2, ...)
   
 }
 
 .cdf <- function(dt, timeStep, variable, variable2Axe = NULL, minValue = NULL, maxValue = NULL,
-                 main = NULL, ylab = NULL, highlight = FALSE, stepPlot = FALSE, drawPoints = FALSE, ...) {
+                 main = NULL, ylab = NULL, highlight = FALSE, stepPlot = FALSE, drawPoints = FALSE, language = "en", ...) {
   
-  uniqueElements <- sort(unique(dt$element))
+  uniqueElements <- as.character(sort(unique(dt$element)))
   
   xbins <- .getXBins(dt$value, minValue, maxValue)$xbins
   
@@ -77,8 +102,13 @@
   dt <- dt[, .getCDF(value), by = element]
   
   variable <- paste0(variable, collapse = " ; ")
-  if (is.null(ylab)) ylab <- "Proportion of time steps"
-  if (is.null(main) | isTRUE(all.equal("", main))) main <- paste("Cumulated distribution of", variable)
+  if (is.null(ylab)){
+    ylab <- .getLabelLanguage("Proportion of time steps", language)
+  } 
+
+  if (is.null(main) | isTRUE(all.equal("", main))){
+    main <-  paste(.getLabelLanguage("Cumulated distribution of", language), variable)
+  } 
   
   .plotStat(dt, ylab = ylab, main = main, uniqueElements = uniqueElements, variable2Axe = variable2Axe,
             highlight = highlight, stepPlot = stepPlot, drawPoints = drawPoints, ...)
@@ -114,7 +144,7 @@
 .plotStat <- function(dt, ylab, main, colors, uniqueElements, 
                       legend, legendItemsPerRow, width, height,
                       plotConfInt = FALSE, highlight = FALSE,
-                      stepPlot = FALSE, drawPoints = FALSE,variable2Axe = NULL, ...) {
+                      stepPlot = FALSE, drawPoints = FALSE,variable2Axe = NULL, language = "en", ylab2 = NULL, ...) {
   dt <- dcast(dt, x ~ element, value.var = "y")
   
   if (is.null(colors)) {
@@ -124,10 +154,16 @@
   }
   legendId <- sample(1e9, 1)
   
+  if(length(uniqueElements) == 1){
+    dycol <- colors[1]
+  } else {
+    dycol <- NULL
+  }
+  
   g <- dygraph(as.data.frame(dt), main = main, group = legendId) %>% 
     dyOptions(
       includeZero = TRUE, 
-      colors = colors,
+      colors = dycol,
       gridLineColor = gray(0.8), 
       axisLineColor = gray(0.6), 
       axisLabelColor = gray(0.6), 
@@ -138,31 +174,31 @@
     dyAxis("y", label = ylab, pixelsPerLabel = 60) %>% 
     dyLegend(show = "never") %>% 
     dyCallbacks(
-      highlightCallback = JS_updateLegend(legendId, timeStep = "none"),
+      highlightCallback = JS_updateLegend(legendId, timeStep = "none", language = language),
       unhighlightCallback = JS_resetLegend(legendId)
     )
   
-  
-  if(length(variable2Axe)>0){
-    for( i in variable2Axe)
-    {
-      g <- g %>%   dySeries(i, axis = 'y2')
-    } 
+  for(i in 1:length(uniqueElements)){
+    if(!uniqueElements[i] %in% variable2Axe){
+      g <- g %>% dySeries(uniqueElements[i], color = colors[i])
+    } else {
+      g <- g %>% dySeries(uniqueElements[i], axis = 'y2', color = colors[i])
+    }
   }
   
-  
-  if(highlight)
-  {
+  if(highlight){
     g  <- g  %>% dyHighlight(highlightSeriesOpts = list(strokeWidth = 2))
   }
   
+  if(!is.null(ylab2)){
+    g  <- g  %>% dyAxis("y2", label = ylab2)
+  }
+  
   if (plotConfInt) {
     for (v in uniqueElements) {
       axis = NULL
-      if(length(variable2Axe)>0)
-      {
-        if(v%in%variable2Axe)
-        {
+      if(length(variable2Axe)>0){
+        if(v%in%variable2Axe){
           axis <- "y2"
         } 
       }
